pub struct Time(/* private fields */);Expand description
A wrapper type for chrono::NaiveTime.
Implementations
sourceimpl Time
impl Time
sourcepub fn try_new(hour: u32, minute: u32, second: u32) -> Result<Self, Error>
pub fn try_new(hour: u32, minute: u32, second: u32) -> Result<Self, Error>
Attempts to create a new instance.
sourcepub fn num_secs_from_midnight(&self) -> u32
pub fn num_secs_from_midnight(&self) -> u32
Returns the number of non-leap seconds past the last midnight.
sourcepub fn num_millis_from_midnight(&self) -> u32
pub fn num_millis_from_midnight(&self) -> u32
Returns the number of non-leap milliseconds past the last midnight.
sourcepub fn num_micros_from_midnight(&self) -> u32
pub fn num_micros_from_midnight(&self) -> u32
Returns the number of non-leap microseconds past the last midnight.
sourcepub fn format(&self, fmt: &str) -> String
pub fn format(&self, fmt: &str) -> String
Formats the time with the specified format string.
See format::strftime for the supported escape sequences.
sourcepub fn duration_since(&self, earlier: Time) -> Duration
pub fn duration_since(&self, earlier: Time) -> Duration
Returns the amount of time elapsed from another time to this one, or zero duration if that time is later than this one.
sourcepub fn span_between(&self, other: Time) -> Duration
pub fn span_between(&self, other: Time) -> Duration
Returns the duration of time between self and other.
sourcepub fn span_between_now(&self) -> Duration
pub fn span_between_now(&self) -> Duration
Returns the duration of time between self and Time::now().
sourcepub fn span_before_now(&self) -> Option<Duration>
pub fn span_before_now(&self) -> Option<Duration>
Returns the duration of time from self to Time::now().
sourcepub fn span_after_now(&self) -> Option<Duration>
pub fn span_after_now(&self) -> Option<Duration>
Returns the duration of time from Time::now() to self.