Struct edm_core::schedule::AsyncJobScheduler
source · pub struct AsyncJobScheduler { /* private fields */ }Expand description
A type contains and executes the async scheduled jobs.
Implementations
sourceimpl AsyncJobScheduler
impl AsyncJobScheduler
sourcepub fn add(&mut self, job: AsyncJob) -> Uuid
pub fn add(&mut self, job: AsyncJob) -> Uuid
Adds an async job to the scheduler and returns the job ID.
sourcepub fn get(&self, job_id: Uuid) -> Option<&AsyncJob>
pub fn get(&self, job_id: Uuid) -> Option<&AsyncJob>
Returns a reference to the job with the ID.
sourcepub fn get_mut(&mut self, job_id: Uuid) -> Option<&mut AsyncJob>
pub fn get_mut(&mut self, job_id: Uuid) -> Option<&mut AsyncJob>
Returns a mutable reference to the job with the ID.
sourcepub fn time_till_next_job(&self) -> Duration
pub fn time_till_next_job(&self) -> Duration
Returns the duration till the next job is supposed to run.